@@ -19,50 +19,48 @@
 #
 
 from __future__ import absolute_import
+from __future__ import division
 
 import logging
+import os
 import socket
+
+import six
+
 from vdsm.common.define import Mbytes
 from vdsm.config import config
 from vdsm import throttledlog
 
 from vdsm.common.cpuarch import PAGE_SIZE_BYTES
+from vdsm.common import unixrpc
 
-try:
-    import mom
-    from mom import unixrpc
-    _momAvailable = True
-except ImportError:
-    _momAvailable = False
 
 throttledlog.throttle('MomNotAvailable', 100)
 throttledlog.throttle('MomNotAvailableKSM', 100)
 
 
-class MomNotAvailableError(RuntimeError):
-    pass
-
-
 class MomClient(object):
 
-    def __init__(self, momconf, conf_overrides=None):
-        if not _momAvailable:
-            raise MomNotAvailableError()
-
+    def __init__(self, sock_path):
         self.log = logging.getLogger("MOM")
         self.log.info("Preparing MOM interface")
-
-        # MOM instance is needed to load the config file and get the RPC port
-        _mom = mom.MOM(momconf, conf_overrides)
-        port = _mom.config.get('main', 'rpc-port')
-        if port == "-1":
-            self.log.error("MOM's RPC interface is disabled")
-            raise MomNotAvailableError()
-
-        self.log.info("Using named unix socket " + port)
-        self._mom = unixrpc.UnixXmlRpcClient(port)
+        self._sock_path = sock_path
+        self._mom = None
         self._policy = {}
 
+    def connect(self):
+        if self._mom is not None:
+            return
+
+        if os.access(self._sock_path, os.W_OK):
+            self.log.info("MOM: Using named unix socket: %s",
+                          self._sock_path)
+            self._mom = unixrpc.UnixXmlRpcClient(self._sock_path)
+        else:
+            self.log.info("MOM: named unix socket %s missing, not available",
+                          self._sock_path)
+            self._mom = None
+
     def getKsmStats(self):
         """
         Get information about KSM and convert memory data from page
@@ -77,7 +75,7 @@ class MomClient(object):
             ret['ksmPages'] = stats['ksm_pages_to_scan']
             ret['ksmMergeAcrossNodes'] = bool(stats['ksm_merge_across_nodes'])
             ret['memShared'] = stats['ksm_pages_sharing'] * PAGE_SIZE_BYTES
-            ret['memShared'] /= Mbytes
+            ret['memShared'] //= Mbytes
             ret['ksmCpu'] = stats['ksmd_cpu_usage']
         except (AttributeError, socket.error):
             throttledlog.warning('MomNotAvailableKSM',
@@ -104,7 +102,7 @@ class MomClient(object):
         # Python bool values are defined in 00-defines.policy so need no
         # conversion here
         policy_string = "\n".join(["(set %s %r)" % (k, v)
-                                   for k, v in self._policy.iteritems()])
+                                   for k, v in six.iteritems(self._policy)])
 
         try:
             self._mom.setNamedPolicy(config.get("mom", "tuning_policy"),
