@@ -17,7 +17,9 @@
 #
 # Refer to the README and COPYING files for full details of the license
 #
+
 from __future__ import absolute_import
+from __future__ import division
 
 import itertools
 import json
@@ -179,14 +181,7 @@ def _normalize_lshw_result(result):
     `lshw -json` does not return a valid JSON in case of several results for
      the same device class, [] brackets are missing in the result.
     """
-    # TODO: On fc27, output in json format is faulty, remove when resolved.
-    # BZ#1543320
-    try:
-        return json.loads('[' + result + ']')
-    except ValueError:
-        if os.path.exists('/etc/fedora-release'):
-            return json.loads('[]')
-        raise
+    return json.loads('[' + result + ']')
 
 
 def _get_hw_addr(dev_name):
