@@ -18,6 +18,7 @@
 #
 
 from __future__ import absolute_import
+from __future__ import division
 
 import os
 
@@ -28,11 +29,12 @@ from vdsm.common import libvirtconnection
 from vdsm.network.api import DUMMY_BRIDGE
 from . import expose, ExtraArgsError
 
-EXT_BRCTL = '/usr/sbin/brctl'
+EXT_IP = '/usr/sbin/ip'
 
 
 def createEphemeralBridge(bridgeName):
-    rc, out, err = commands.execCmd([EXT_BRCTL, 'addbr', bridgeName])
+    rc, out, err = commands.execCmd([
+        EXT_IP, 'link', 'add', bridgeName, 'type', 'bridge'])
     if rc != 0:
         raise EnvironmentError(
             'Failed to create ephemeral dummy bridge. Err: %s' % err
@@ -40,7 +42,8 @@ def createEphemeralBridge(bridgeName):
 
 
 def removeEphemeralBridge(bridgeName):
-    rc, out, err = commands.execCmd([EXT_BRCTL, 'delbr', bridgeName])
+    rc, out, err = commands.execCmd([
+        EXT_IP, 'link', 'del', bridgeName, 'type', 'bridge'])
     if rc != 0:
         raise EnvironmentError(
             'Failed to remove ephemeral dummy bridge. Err: %s' % err
