@@ -20,6 +20,7 @@
 # pylint: disable=no-member
 
 from __future__ import absolute_import
+from __future__ import division
 
 import collections
 import os
@@ -124,7 +125,7 @@ class Drive(core.Base):
                  'extSharedState', 'drv', 'sgio', 'GUID', 'diskReplicate',
                  '_diskType', 'hosts', 'protocol', 'auth', 'discard',
                  'vm_custom', 'blockinfo', '_threshold_state', '_lock',
-                 '_monitorable', 'guestName',)
+                 '_monitorable', 'guestName', '_iotune')
     VOLWM_CHUNK_SIZE = (config.getint('irs', 'volume_utilization_chunk_mb') *
                         constants.MEGAB)
     VOLWM_FREE_PCT = 100 - config.getint('irs', 'volume_utilization_percent')
@@ -231,6 +232,7 @@ class Drive(core.Base):
         self.device = kwargs.get('device', 'disk')
         # Must be initialized for getXML.
         self.propagateErrors = 'off'
+        self._iotune = {}
         super(Drive, self).__init__(log, **kwargs)
         if not hasattr(self, 'vm_custom'):
             self.vm_custom = {}
@@ -340,7 +342,7 @@ class Drive(core.Base):
         When the LV usage reaches this limit an extension is in order (thin
         provisioning on block devices).
         """
-        return self.VOLWM_FREE_PCT * self.volExtensionChunk / 100
+        return self.VOLWM_FREE_PCT * self.volExtensionChunk // 100
 
     def getNextVolumeSize(self, curSize, capacity):
         """
@@ -671,10 +673,6 @@ class Drive(core.Base):
         return ("./devices/disk/source[@%s='%s']" %
                 (source_key[self.diskType], self.path))
 
-    def is_attached_to(self, xml_string):
-        dom = ET.fromstring(xml_string)
-        return bool(dom.findall(self._xpath))
-
     def __repr__(self):
         return ("<Drive name={self.name}, type={self.diskType}, "
                 "path={self.path} threshold={self.threshold_state} "
@@ -682,13 +680,13 @@ class Drive(core.Base):
 
     @property
     def iotune(self):
-        return self.specParams.get('ioTune', {}).copy()
+        return self._iotune.copy()
 
     @iotune.setter
     def iotune(self, value):
         iotune = value.copy()
         vmtune.validate_io_tune_params(iotune)
-        self.specParams['ioTune'] = iotune
+        self._iotune = iotune
 
     def volume_target_index(self, vol_id, actual_chain):
         """
@@ -907,6 +905,31 @@ def image_id(path):
     return os.path.basename(image_path)
 
 
+def disable_dynamic_ownership(element):
+    """
+    Disable dynamic ownership in the given device element.
+
+    Generally all devices should be put under dynamic ownership.  However it's
+    more complicated with storage devices.  Vdsm handles volumes throughout
+    their lifetimes, and lifetime of a volume exceeds lifetime of a VM.  It's
+    therefore not possible for VDSM to forgive all the permission handling.
+
+    Arguments:
+      element: etree element representing the device
+    """
+    # We need to make sure that libvirt DAC (fs permission driver) is
+    # disabled. The libvirt spec may be hard to read at times, so just as a
+    # help:
+    #  model='dac' -- dac is the FS permissions driver
+    #  type='none' -- type is currently used for SELinux/AppArmor drivers
+    #  relabel='no' -- disable the change of permissions itself
+    seclabel = ET.Element('seclabel')
+    seclabel.set('type', 'none')
+    seclabel.set('relabel', 'no')
+    seclabel.set('model', 'dac')
+    element.append(seclabel)
+
+
 def _getSourceXML(drive):
     """
     Makes a libvirt <source> element for specified drive.
@@ -919,19 +942,27 @@ def _getSourceXML(drive):
         Element: libvirt source element in a form of
                  <source file='/image'/>
     """
+    needs_seclabel = False
+
     source = vmxml.Element('source')
     if drive["diskType"] == DISK_TYPE.BLOCK:
+        needs_seclabel = True
         source.setAttrs(dev=drive["path"])
     elif drive["diskType"] == DISK_TYPE.NETWORK:
         source.setAttrs(protocol=drive["protocol"], name=drive["path"])
         for host in drive["hosts"]:
             source.appendChildWithArgs('host', **host)
     elif drive["diskType"] == DISK_TYPE.FILE:
+        needs_seclabel = True
         source.setAttrs(file=drive["path"])
         if drive["device"] == 'cdrom' or drive["device"] == 'floppy':
             source.setAttrs(startupPolicy='optional')
     else:
         raise RuntimeError("Unsupported diskType %r", drive["diskType"])
+
+    if needs_seclabel:
+        disable_dynamic_ownership(source)
+
     return source
 
 
